summaryrefslogtreecommitdiffstats
path: root/server/src/com/vaadin/ui/UI.java
diff options
context:
space:
mode:
authorLeif Åstrand <leif@vaadin.com>2012-09-03 13:57:20 +0300
committerLeif Åstrand <leif@vaadin.com>2012-09-03 14:05:31 +0300
commit6f276f4451cb185919084181b54fb84532a1d984 (patch)
tree698b9459b867349aae9de5f26ebefa7dd1f3b81d /server/src/com/vaadin/ui/UI.java
parent3dd5a4824cda3dd7842c937a618feebc2b1a0f27 (diff)
downloadvaadin-framework-6f276f4451cb185919084181b54fb84532a1d984.tar.gz
vaadin-framework-6f276f4451cb185919084181b54fb84532a1d984.zip
Combine ApplicationServlet and AAS and rename to VaadinServlet (#9460)
Diffstat (limited to 'server/src/com/vaadin/ui/UI.java')
-rw-r--r--server/src/com/vaadin/ui/UI.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/server/src/com/vaadin/ui/UI.java b/server/src/com/vaadin/ui/UI.java
index d1ccaacde3..0f914d3947 100644
--- a/server/src/com/vaadin/ui/UI.java
+++ b/server/src/com/vaadin/ui/UI.java
@@ -33,7 +33,6 @@ import com.vaadin.event.Action.Handler;
import com.vaadin.event.ActionManager;
import com.vaadin.event.MouseEvents.ClickEvent;
import com.vaadin.event.MouseEvents.ClickListener;
-import com.vaadin.server.AbstractApplicationServlet;
import com.vaadin.server.LegacyComponent;
import com.vaadin.server.Page;
import com.vaadin.server.Page.BrowserWindowResizeEvent;
@@ -41,6 +40,7 @@ import com.vaadin.server.Page.BrowserWindowResizeListener;
import com.vaadin.server.PaintException;
import com.vaadin.server.PaintTarget;
import com.vaadin.server.Resource;
+import com.vaadin.server.VaadinServlet;
import com.vaadin.server.WrappedRequest;
import com.vaadin.server.WrappedRequest.BrowserDetails;
import com.vaadin.shared.EventId;
@@ -63,7 +63,7 @@ import com.vaadin.tools.ReflectTools;
* </p>
* <p>
* When a new UI instance is needed, typically because the user opens a URL in a
* browser window which points to {@link AbstractApplicationServlet},
* {@link Application#getUIForRequest(WrappedRequest)} is invoked to get a UI.
* That method does by default create a UI according to the
* {@value Application#UI_PARAMETER} parameter from web.xml.
@@ -63,7 +63,7 @@ import com.vaadin.tools.ReflectTools;
* <p>
* When a new UI instance is needed, typically because the user opens a URL in a
- * browser window which points to {@link AbstractApplicationServlet},
+ * browser window which points to {@link VaadinServlet},
* {@link Application#getUIForRequest(WrappedRequest)} is invoked to get a UI.
* That method does by default create a UI according to the